@@ -28,6 +28,8 @@
  * @section DESCRIPTION
  *
  * This file declares the TileDB C API for serialization.
+ * APIs defined in this header are currently unstable and subject to breaking
+ * changes between minor releases.
  */
 
 #ifndef TILEDB_SERIALIZATION_H
@@ -106,6 +108,7 @@ TILEDB_EXPORT int32_t tiledb_serialize_array(
  * @param client_side Allows to specify different behavior depending on who is
  * serializing, the client (1) or the Cloud server (0). This is sometimes needed
  * since they are both using the same Core library APIs for serialization.
+ * @param array_uri uri of the array to deserialize.
  * @param array Will be set to a newly allocated array.
  * @return `TILEDB_OK` for success and `TILEDB_ERR` for error.
  */
@@ -114,6 +117,7 @@ TILEDB_EXPORT int32_t tiledb_deserialize_array(
     const tiledb_buffer_t* buffer,
     tiledb_serialization_type_t serialize_type,
     int32_t client_side,
+    const char* array_uri,
     tiledb_array_t** array) TILEDB_NOEXCEPT;
 
 /**
@@ -157,6 +161,26 @@ TILEDB_EXPORT int32_t tiledb_deserialize_array_schema(
     int32_t client_side,
     tiledb_array_schema_t** array_schema) TILEDB_NOEXCEPT;
 
+/**
+ * Deserializes an array creation request from the given buffer.
+ *
+ * @param ctx The TileDB context.
+ * @param buffer Buffer to deserialize from
+ * @param serialization_type Type of serialization to use
+ * @param client_side Allows to specify different behavior depending on who is
+ * serializing, the client (1) or the Cloud server (0). This is sometimes needed
+ * since they are both using the same Core library APIs for serialization.
+ * @param array_schema Will be set to a newly created array schema.
+ * @return `TILEDB_OK` for success and `TILEDB_ERR` for error.
+ */
+TILEDB_EXPORT int32_t tiledb_deserialize_array_create(
+    tiledb_ctx_t* ctx,
+    const tiledb_buffer_t* buffer,
+    tiledb_serialization_type_t serialize_type,
+    int32_t client_side,
+    tiledb_string_t** storage_uri,
+    tiledb_array_schema_t** array_schema) TILEDB_NOEXCEPT;
+
 /**
  * Serializes the given array open information into the given buffer.
  *
@@ -414,7 +438,7 @@ TILEDB_EXPORT int32_t tiledb_deserialize_array_non_empty_domain_all_dimensions(
 /**
  * Serializes the array max buffer sizes information into the given buffer.
  *
- * @note The caller must free the returned `tiledb_buffer_t`.
+ * This API is deprecated and using it will always return an error.
  *
  * @param ctx The TileDB context.
  * @param array Array to which the subarray belongs to
@@ -422,9 +446,9 @@ TILEDB_EXPORT int32_t tiledb_deserialize_array_non_empty_domain_all_dimensions(
  * @param serialization_type Type of serialization to use
  * @param buffer Will be set to a newly allocated buffer containing the
  *      serialized max buffer sizes.
- * @return `TILEDB_OK` for success and `TILEDB_ERR` for error.
+ * @return `TILEDB_ERR`
  */
-TILEDB_EXPORT int32_t tiledb_serialize_array_max_buffer_sizes(
+TILEDB_DEPRECATED_EXPORT int32_t tiledb_serialize_array_max_buffer_sizes(
     tiledb_ctx_t* ctx,
     const tiledb_array_t* array,
     const void* subarray,
@@ -773,6 +797,7 @@ TILEDB_EXPORT capi_return_t tiledb_handle_load_array_schema_request(
  *
  * @param ctx The TileDB context.
  * @param array The TileDB Array.
+ * @param serialization_type The type of Cap'n Proto serialization used.
  * @param request A buffer containing the LoadEnumerationsRequest Capnp message.
  * @param response An allocated buffer that will contain the
  *        LoadEnumerationsResponse Capnp message.
@@ -785,6 +810,43 @@ TILEDB_EXPORT capi_return_t tiledb_handle_load_enumerations_request(
     const tiledb_buffer_t* request,
     tiledb_buffer_t* response) TILEDB_NOEXCEPT;
 
+/**
+ * Process a query plan request.
+ *
+ * @param ctx The TileDB context.
+ * @param array The TileDB Array.
+ * @param serialization_type The type of Cap'n Proto serialization used.
+ * @param request A buffer containing the QueryPlanRequest Capnp message.
+ * @param response An allocated buffer that will contain the QueryPlanResponse
+ * Capnp message.
+ * @return capi_return_t TILEDB_OK on success, TILEDB_ERR on error.
+ */
+TILEDB_EXPORT capi_return_t tiledb_handle_query_plan_request(
+    tiledb_ctx_t* ctx,
+    tiledb_array_t* array,
+    tiledb_serialization_type_t serialization_type,
+    const tiledb_buffer_t* request,
+    tiledb_buffer_t* response) TILEDB_NOEXCEPT;
+
+/**
+ * Process a consolidation plan request.
+ *
+ * @param ctx The TileDB context.
+ * @param array The TileDB Array.
+ * @param serialization_type The type of Cap'n Proto serialization used.
+ * @param request A buffer containing the ConsolidationPlanRequest Capnp
+ * message.
+ * @param response An allocated buffer that will contain the
+ * ConsolidationPlanResponse Capnp message.
+ * @return capi_return_t TILEDB_OK on success, TILEDB_ERR on error.
+ */
+TILEDB_EXPORT capi_return_t tiledb_handle_consolidation_plan_request(
+    tiledb_ctx_t* ctx,
+    tiledb_array_t* array,
+    tiledb_serialization_type_t serialization_type,
+    const tiledb_buffer_t* request,
+    tiledb_buffer_t* response) TILEDB_NOEXCEPT;
+
 #ifdef __cplusplus
 }
 #endif
