@@ -7,7 +7,7 @@
 #  define TILEDB_NO_EXPORT
 #else
 #  ifndef TILEDB_EXPORT
-#    ifdef TILEDB_CORE_OBJECTS_EXPORTS
+#    ifdef tiledb_EXPORTS
         /* We are building this library */
 #      define TILEDB_EXPORT __attribute__((visibility("default")))
 #    else
@@ -33,6 +33,7 @@
 #  define TILEDB_DEPRECATED_NO_EXPORT TILEDB_NO_EXPORT TILEDB_DEPRECATED
 #endif
 
+/* NOLINTNEXTLINE(readability-avoid-unconditional-preprocessor-if) */
 #if 0 /* DEFINE_NO_DEPRECATED */
 #  ifndef TILEDB_NO_DEPRECATED
 #    define TILEDB_NO_DEPRECATED
